@@ -3,10 +3,11 @@ import os.path
 # from appserver import Application
 from paxd.server.controller import Controller
 
-def main():
-    c = Controller('3489y3ngyqr87gy32r8fnyehwiufhe98')
+def main(id):
+    c = Controller(id)
     c.run()
 
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    import sys
+    main(sys.argv[1])
\ No newline at end of file
